
// arduino "proximity" sketch   version 1.0   J.Luke (RobotBits.co.uk), modified
// by Linux User & Developer
//
// A simple sketch to help you get started with an Arduino powered frindo robot
//
// This example has been written for the frindo open source robotics platform and uses
// two bi-directional motors controlled by an Arduino and a RobotShield
//
// This sketch uses the RobotShield library which includes a series of functions that perform 
// the different types of movement for your robot including:
//
//     forward, reverse, stop, rotate clock-wise, rotate counter clock-wise, 
//     turn_left and turn_right 
//
// To program the movement of your robot simply call the functions as needed
// from the main loop
//
// This example is a 3 sensor "proximity alert" application. The robot will move forward continuously 
// until it's very close to a wall. This application uses 3 infrared sensors (forward, left & right)
// connected to Analogue 0, 1 & 2. Although these are analogue sensors, the code below has a threshold 
// detector for each sensor creating simple "bump sensors"
//
// For support, please use the frindo support forum at www.frindo.org



#include <RobotShield.h> // include the RobotShield library

RobotShield rs;          // create an instance of the RobotShield class called "rs"


// define the analogue pins used by IR Sensor
int FrontBump = 0;       // Front IR sensor connected to pin 0
int RightBump = 1;       // Right-hand IR sensor (as viewed from rear) connected to pin 1
int LeftBump = 2;        // Left-hand IR sensor (as viewed from rear) connected to pin 2
int RearBump = 3;        // Rear IR sensor connected to pin 4

// define variables used

int bump;
int left;
int right;
int rear;

int frontTrigger = 200;    // define the threshold at which bump events are detected
int sideTrigger = 100;
int rearTrigger = 100;


void setup() {       
                      
              Serial.begin(9600);             // set up serial port
             }



int front_bump() {                            // check for front bump, if bump detected return 1
  
            bump = analogRead(FrontBump);      // read front IR sensor
            
            if(bump > frontTrigger){                 // look for bump             
                return 1;
                } 
            else {  
                return 0;
                }                
            }
            
            
int left_bump() {                            // check for left-hand bump, if bump detected return 1
  
            left = analogRead(LeftBump);      // read left-hand IR sensor
            
            if(left > sideTrigger){                 // look for bump             
                return 1;
                } 
            else {  
                return 0;
                }                
            }
            
            
int right_bump() {                            // check for right-hand bump, if bump detected return 1
  
            right = analogRead(RightBump);      // read right-hand IR sensor
            
            if(right > sideTrigger){                 // look for bump             
                return 1;
                } 
            else {  
                return 0;
                }                
            }
 
int rear_bump() {                            // check for rear bump sensor, if bump detected return 1
  
            rear = analogRead(RearBump);      // read rear IR sensor
            
            if(rear > rearTrigger){                 // look for bump             
                return 1;
                } 
            else {  
                return 0;
                }                
            }           
            
            
void loop() { 
  
            Serial.println("Here we go...");
            
            while(!front_bump()){      // while there is no bump keep going forward (about 10cm with GPD120)
            
                if(!left_bump() && !right_bump()) { 
                    Serial.println("NO bump detected - move forward");
                    rs.forward(500, 200);                 // move forward for 500 mS at speed 200 (200/255ths of full speed)   
                }
                
                else if(left_bump() && !right_bump())  {
                    Serial.println("LEFT bump detected - wrong angle");
                    rs.rot_ccw(100, 200);                 // turn right for 100 mS at speed 200 (200/255ths of full speed)      
                }
                
                else if(!left_bump() && right_bump())  {
                    Serial.println("RIGHT bump detected - wrong angle");
                    rs.rot_cw(100, 200);                 // turn left for 100 mS at speed 200 (200/255ths of full speed)       
                }
                    
            }
            
            while(front_bump()){    // while the front bump is there, get ready to stop
            
                if(!left_bump() && !right_bump()) { 
                    Serial.println("Almost there - move forward");
                    rs.forward(100, 200);                 // move forward for 100 mS at speed 200 (200/255ths of full speed)   
                }
                
                else if(left_bump() && !right_bump())  {
                    Serial.println("LEFT bump detected - just a little more");
                    rs.rot_ccw(100, 200);                 // turn right for 100 mS at speed 200 (200/255ths of full speed)      
                }
                
                else if(!left_bump() && right_bump())  {
                    Serial.println("RIGHT bump detected - just a little more");
                    rs.rot_cw(100, 200);                 // turn left for 100 mS at speed 200 (200/255ths of full speed)       
                }
                
                else if(left_bump() && right_bump())  {
                    Serial.println("BOTH bump detected - we're here!");
                    rs.stop;                             // stop       
                }
                    
            }
      } 
